@@ -1,6 +1,7 @@
 import argparse
 import json
 from multiprocessing import Process, Queue
+from time import time
 import tomli
 import re
 from typing import Dict
@@ -8,10 +9,10 @@ import yaml
 
 from . import __version__
 from .server import run_server
-from .mytypes import RunFn, SetupFn
-from .config import Config, g_config
+from .config import Config
+from .sources.mytypes import RunFn, SetupFn
 
-from .sources import demo, rpctask, approach, confighelp
+from .sources import demo, rpctask, approach, smol, flightgear, confighelp
 
 
 def main():
@@ -34,23 +35,32 @@ def main():
                         help='hosts to accept for web page', default='0.0.0.0')
     parser.add_argument('-P', '--http-port', type=int,
                         help='port to serve the web page on', default=5555)
+    parser.add_argument('-U', '--passthrough-host', type=str,
+                        help='address to forward state to (e.g. 127.0.0.1)')
+    parser.add_argument('-O', '--passthrough-port', type=int,
+                        help='port to forward the state to (e.g. 50010)')
     subparsers = parser.add_subparsers(title='source', required=True, dest='source',
                                        help='source name', description='select where to get aircraft state')
 
     sources: Dict[str, RunFn] = {}
-    for source_module in [demo, rpctask, approach, confighelp]:
+    for source_module in [demo, rpctask, approach, smol, flightgear, confighelp]:
         setup: SetupFn = source_module.setup
         name, run_function = setup(subparsers)
         sources[name] = run_function
 
     args = parser.parse_args()
+    passthrough_host = args.passthrough_host is None
+    passthrough_port = args.passthrough_port is None
+    if passthrough_host != passthrough_host:
+        parser.error(
+            'For passthrough UDP, both address (-U) and port (-O) must be specified')
+
     args.verbosity -= args.quiet
     if args.verbosity >= 1:
-        # mimic = specifier from python 3.8 to maintain 3.7 compatibility
+        # mimic '=' specifier from python 3.8 to maintain 3.7 compatibility
         print(f'args={args}')
 
-    global g_config
-    g_config = Config()
+    config = Config()
     if args.config is not None:
         for config_filename in args.config.split(','):
             config_filename: str
@@ -65,20 +75,21 @@ def main():
                 parser.error(
                     'Config files have to end with ".json", ".yaml", ".yml" or ".toml" to detect correct parser type')
             if update_dict is not None:
-                g_config = g_config.updated(update_dict)
+                config = config.updated(update_dict)
     if args.config_keys is not None:
         # FIXME: does not handle single quote escaping
         separator = re.compile(
             r"""(?!\B"[^"]*),(?![^"]*"\B)""")  # comma not between double quotes
         toml_string = '\n'.join(re.split(separator, args.config_keys))
         update_dict = tomli.loads(toml_string)
-        g_config = g_config.updated(update_dict)
+        config = config.updated(update_dict)
+    if config.start_time is None:
+        config.start_time = time()
     if args.verbosity >= 1:
-        print(f'g_config=Config({g_config})')
+        print(f'config=Config({config})')
 
     queue = Queue()
-    server_process = Process(target=run_server, args=(
-        g_config, queue, args.http_host, args.http_port, args.verbosity))
+    server_process = Process(target=run_server, args=(queue, args, config))
     server_process.start()
 
     if args.verbosity >= 0 and not args.source.endswith('help'):
@@ -89,7 +100,7 @@ Lidia GUIs driven by '{args.source}' source served on:
     - Ship Approach: http://localhost:{args.http_port}/approach""")
 
     try:
-        (sources[args.source])(queue, args)
+        (sources[args.source])(queue, args, config)
 
     except KeyboardInterrupt:
         if args.verbosity >= 0 and not args.source.endswith('help'):
