@@ -1,12 +1,7 @@
-from argparse import _SubParsersAction, Namespace
-from multiprocessing import Queue
-from typing import Callable, List, NoReturn, Tuple, Self
+from typing import List
 from pydantic import BaseModel, Extra
 from pydantic.utils import deep_update
 
-RunFn = Callable[[Queue, Namespace], NoReturn]
-SetupFn = Callable[[_SubParsersAction], Tuple[str, RunFn]]
-
 
 # HACK: These classes rely on iteration through dict of fields in the order they were defined
 #       So far observed to work in CPython, but isn't guaranteed by language implementations
@@ -45,7 +40,7 @@ class IntFlagModel(BaseModel):
 class NestingModel(BaseModel, extra=Extra.forbid):
     """Extension to `pydantic.BaseModel` allowing for updating with nested dictionary"""
 
-    def updated(self, update_dict: dict[str, object]) -> Self:
+    def updated(self, update_dict: dict[str, object]) -> 'NestingModel':
         """Construct new model, overriding values provided in nested dictionary
 
         The data is validated, both for type and not having keys undefined in the model"""
